<!DOCTYPE html>
<html lang="zh">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <script src="/static/django_sohoui/js/vue.js"></script>
    <script src="/static/django_sohoui/js/index.js"></script>
    <script src="/static/django_sohoui/js/jquery.min.js"></script>
    <script src="/static/django_sohoui/js/axios.min.js"></script>
    <link rel="stylesheet" href="/static/django_sohoui/css/index.css">
    <!-- 引入 Font Awesome -->
    <link rel="stylesheet" href="/static/ui_template/css/all.min.css">
    
    {% block header_js_css %}
    {% endblock %}
    <title>{% block title %}{% endblock %}</title>
    <style>
        body {
            display: flex;
            margin: 0;
            height: 100%;
            font-family: Arial, sans-serif;
            overflow: hidden;
        }
        html{
            height: 100%;
        }
        #aside{
            height: 100% !important;
            width: auto !important;
        }
        .el-menu-vertical-demo:not(.el-menu--collapse) {
            min-width: 210px;
            min-height: 100%;
        }
        .el-aside{
            height: 100% !important;
            width: auto !important;
        }
        .container {
            flex: 1; /* 使容器占据剩余空间 */
            display: flex;
            flex-direction: column;
        }

        .icon-header i{
            width: 20px;
            height: 20px;
        }
        .icon-header{
            width: 56px;
            height: 56px;
            display: flex;
            align-items: center;
            justify-content: center;
            float: left;
        }
        .icon-header:hover{
            background-color: #b7cbe0;
        }
        .icon-header-user{
            width: 100px;
        }
        .change_password_down{
            text-decoration: none;
            color: #606266;
        }
        .logout-btn{
            color: #606266 !important; 
            font-weight: unset !important;
        }
        .el-row-tabs{
            height: 55px;
            border-bottom: 1px solid #e6e6e6;
            border-top: 1px solid #e6e6e6;
            line-height: 55px;
            overflow: hidden;
        }
        .span-tabs{
            padding: 2px 15px;
            border: 1px solid #e6e6e6;
            border-radius: 5px;
            background-color: #b7cbe0;
            color: #0F5197;
        }
        .active-tabs{
            background-color: #0F5197;
            color: #fff;
        }
        .el-icon-close{
            padding: 2px;
            color: #fff;
        }
        .el-icon-close:hover{
            background-color: #e6e6e6; 
            border-radius: 10px;
            text-align: center;
            color: rgb(83, 94, 197) !important;
        }
        .container{
            background-color: #f1f1f1 !important;
        }
        #base_header, #breadcrumb{
            background-color: white !important;
        }
        .icon-menu{
            display: flex;
            align-items: center;
            justify-content: left;
            line-height: 56px;
            cursor: pointer;
        }
        .content-main{
            height: 100% !important;
            /* min-height: 980px !important; */
            padding: 10px;
        }
        .el-tabs__content{
            height: calc(100% - 39px) !important;
            background-color: #f1f1f1 !important;
            margin: 10px;
        }
        .custom-tab {
            overflow: hidden !important;
        }
        #breadcrumb{
            background-color: #f1f1f1 !important;
        }
        .el-tabs__header{
            background-color: white !important;
        }
        
    </style>
</head>
<body>

<aside>
    {% block aside %}
        {% include 'admin/aside.html' %}
    {% endblock %}
</aside>

<div class="container">
    <header>
        {% block header %}
            {% include 'admin/header.html' %}
        {% endblock %}
    </header>
    <div class="content">
        {% block breadcrumb %}
            {% include 'admin/breadcrumb.html' %}
        {% endblock %}
        {% block content %}
        {% block object-tools %}{% endblock %}
        {% endblock %}
    </div>
</div>
{% block footer_js %}
{% endblock %}

</body>
</html>