/* 颜色 */
.el-tabs__nav-scroll {
  background-color: #ffffff;
  border: 1px solid #f1f2f3;
}

.el-tabs--border-card {
  border: 1px solid #f1f2f3;
}

.el-tabs__content {
  background-color: #f8f8f8;
}

/* 这是首页的样式 */
.el-main {
  padding: 0px !important;
}
aside.el-aside.menu {
  height: 1920px;
  background-color: rgb(255, 255, 255) !important;
}

.float-wrap {
  color: #1e85f4 !important;
}

.menu .el-menu-item:hover {
  background-color: #eff0ff !important;
}

aside.el-aside.menu {
  background-color: rgb(255, 255, 255) !important;
}

:root {
  --n-padding-top: 19px;
  --n-padding-bottom: 20px;
  --n-padding-left: 24px;
  --n-font-size: 14px;
  --un-ring-offset-shadow: 0 0 rgb(0 0 0 / 0);
  --un-ring-shadow: 0 0 rgb(0 0 0 / 0);
}

.float-wrap span {
  margin-left: 10px;
  font-size: 16px !important;
  font-weight: 700;
}

/* 第一个板块 */
.container {
  display: flex;
  justify-content: space-between;
  flex-wrap: wrap;
  gap: 15px;
  padding: 10px;
  background-color: #fff;
  margin: 20px 30px;
  border-radius: 8px;
}

.card {
  display: flex;
  align-items: center;
  justify-content: space-between;
  padding: 30px;
  margin: 10px;
  border-radius: 10px;
  box-shadow: 0 4px 10px rgba(0, 0, 0, 0.1);

  flex: 1;

}

.card img {
  width: 50px;
  height: 50px;
}

.card-content {
  display: flex;
  flex-direction: column;
  margin-right: 10px;
}

.number {
  font-size: 2rem !important;
  font-weight: bold;
}

.percent {
  font-size: 1rem;
  margin-left: 10px;
}

.description {
  font-size: 0.8rem;
  color: #808080;
  margin-top: 20px;
}

.percent.negative {
  color: #d9534f;
}

.percent.positive {
  color: #5cb85c;
}

.description-container {
  display: flex;
  align-items: baseline;
}

.card-red {
  background-color: #ffffff;
  /* 默认白色 */

}

.card-blue {
  background-color: #FFCCCB;
  /* 红色 */

}

.card-green {
  background-color: #ADD8E6;
  /* 蓝色 */

}

.card-default {
  background-color: #90EE90;
  /* 绿色 */
}


/* 第二个板块 */
.echarts-container {
  display: flex;
  justify-content: space-between;
}

#one-echarts {
  width: 100%;
  /* 宽度100% */
  height: 500px;
  border-radius: 4px;
  transition: all ease 0.3s;
  padding: 20px;
  margin-left: 30px;
  overflow: hidden;
  background: #ffffff;
  color: #303133;
  border: 1px solid #f1f2f3;
}


#two-echarts {
  width: 100%;
  /* 宽度100% */
  height: 500px;
  border-radius: 4px;
  transition: all ease 0.3s;
  padding: 20px;
  margin: 0px 30px;
  overflow: hidden;
  background: #ffffff;
  color: #303133;
  border: 1px solid #f1f2f3;
}


/* 搜索样式 */
.admin-search {
  margin: 20px 0px;
}

.change-list #content {
  background-color: #f1f4f6 !important;
}

.module {
  margin: 0px !important;
}

.custom-search {
  padding: 20px 30px;
  background-color: #ffffff;
  border-radius: 10px;
  box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
  margin-bottom: 20px;
}

#toolbar {
  margin: 20px 0px;
  padding: 20px;
  background: #fff !important;
  border-radius: 10px;
  /* box-shadow: 0 2px 10px rgb(255, 255, 255); */
  border: none;
  background: none;
}

.simpleui-form-item {
  width: 300px !important;
}

.el-button--primary {
  color: #646cff;
  background-color: #fff !important;
  border-color: #646cff !important;
  font-weight: 400;
  font-family: inherit;
  border-radius: 6px;
  padding: 0px 12px;
}

.input-label {
  font-size: 14px;
  /* 设置字体大小 */
  color: #666;
  /* 设置字体颜色 */
  margin-bottom: 5px;
  /* 设置标签与输入框之间的间距 */
  display: block;
  /* 使标签在输入框上方显示 */
}

.change-list #content {
  margin: 0px 20px;
}

.el-button--danger {
  color: #f5222d;
  background-color: #fff !important;
  border-color: #f5222d !important;
  font-weight: 400;
  font-family: inherit;
  border-radius: 6px;
}

.el-button--danger:focus,
.el-button--danger:hover {
  color: #fff;
  background-color: #f5222d !important;
}

#changelist .actions {
  display: flex;
  justify-content: flex-end;
  align-items: center !important;
}

#changelist .actions .btn-group {
  position: absolute;
  left: 0px;
  right: auto;
}

/* 手机端 */
@media screen and (max-width: 768px) {
  #changelist .actions .btn-group {
    position: absolute;
    left: -7px;
    top: 5px;
    right: auto;
  }
}

#content-main .module {
  margin: 20px 0px !important;
}

/* .simpleui-form {
  display: flex;
  justify-content: space-between;
} */

table thead th .text a {
  font-size: 16px;
}

td,
th {
  text-align: center;
}

.change-list .filtered {
  min-height: 1000px;
}

.el-pagination.is-background .btn-next,
.el-pagination.is-background .btn-prev,
.el-pagination.is-background .el-pager li {
  font-size: 14px !important;
}

#changelist-form .results {
  height: 875px;
}

/*滚动条样式*/
textarea::-webkit-scrollbar {
  width: 4px;
}

textarea::-webkit-scrollbar-thumb {
  border-radius: 10px;
  box-shadow: inset 0 0 5px rgba(0, 0, 0, 0.2);
  background: rgba(0, 0, 0, 0.2);
}

textarea::-webkit-scrollbar-track {
  box-shadow: inset 0 0 5px rgba(0, 0, 0, 0.2);
  border-radius: 0;
  background: rgba(0, 0, 0, 0.1);

}

/*滚动条 start*/
::-webkit-scrollbar {
  width: 8px;
  height: 4px;
  background-color: #F5F5F5;
}

/*定义滚动条轨道 内阴影+圆角*/
::-webkit-scrollbar-track {
  border-radius: 10px;
  -webkit-box-shadow: inset 0 0 5px rgba(0, 0, 0, 0.2);
  background: #ffffff;
}

/*定义滑块 内阴影+圆角*/
::-webkit-scrollbar-thumb {
  border-radius: 6px;
  -webkit-box-shadow: inset 0 0 5px rgba(0, 0, 0, 0.2);
  background: #d4d3d3;
}

::-webkit-scrollbar-thumb:hover {
  border-radius: 6px;
  -webkit-box-shadow: inset 0 0 5px rgba(0, 0, 0, 0.2);
  background: #999999;
}

#result_list {
  width: 100%;
  /* 表格宽度 */
  border-collapse: collapse;
  /* 合并边框 */
}

#changelist table thead th {
  padding: 0;
  white-space: nowrap;
  vertical-align: middle;
  position: sticky;
  top: -1px;
  border: 1px solid #efeff5;
  color: #409eff !important;
  font-size: 16px;
  z-index: 999 !important;
}

thead th.sorted {
  background: var(--darkened-bg);
}

#result_list td {
  padding: 8px;
  /* 内边距 */
}

#pagination {
  margin: 40px 12px;
  text-align: right;
}

tr:nth-child(even),
tr:nth-child(even) .errorlist,
tr:nth-child(odd)+.row-form-errors,
tr:nth-child(odd)+.row-form-errors .errorlist {
  background: #fff;
}

.row2 {
  background: #fff;
}

.change-list .filtered table tbody th {
  padding-right: 1em;
  border: 1px solid #efeff5;
}

#result_list td {
  padding: 8px;
  border: 1px solid #efeff5;
}

td,
th {
  text-align: center;
  border: 1px solid #efeff5;
}

/* .actions .el-button {
  padding: 10px 12px !important;
} */

button.el-button.el-button--default.el-button--small.el-button--primary {
  padding: 8px 15px;
}

.el-button--small,
.el-button--small.is-round {
  padding: 8px 15px;
  font-weight: 400;
  font-family: inherit;
  border-radius: 6px;
}

#content-main .page-header {
  padding: 10px;
}

.object-tools {
  top: 5px;
}

.el-button-group>.el-button:not(:last-child) {
  margin-right: -1px;
  padding: 8px 12px !important;
}

.el-button-group>.el-button:last-child {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
  /* padding: 8px 12px !important; */
}

button.el-button.button-siner.el-button--danger.el-button--small {
  padding: 10px 12px !important;
  margin-top: -1px;
}
button.el-button.button-siner.el-button--primary.el-button--small {
  padding: 10px 12px !important;
  margin-top: -1px;
}
a.el-button.el-button--default.el-button--small {
  /* padding: 0px; */
  padding: 8px 12px !important;
}
.fieldset-h2 {
  /* background: #333 !important; */
  /* color: #fff !important; */
  background: none !important;
  color: #000 !important;
  font-size: 1.2rem !important;
  font-weight: 600 !important;
}

.submit-row{
  margin: 0px !important;
  padding: 0px !important
}

label.required {
  width: auto !important;
}

.form-container {
  display: grid;
  grid-template-columns: repeat(2, 1fr);
  column-gap: 20px;
  row-gap: 10px;
  margin: 10px 0px;
}

.form-row.full-width {
  grid-column: span 2;
}

.form-row label {
  display: block;
  font-weight: bold;
  margin-bottom: 5px;
}

.form-row input,
.form-row select,
.form-row textarea {
  width: 100%;
  padding: 8px;
  box-sizing: border-box;
}

#content #changelist-form {
  padding: 0px 10px !important;
}

.float-wrap span {
  color: #409eff !important;
}

