<div id="app_{{ widget.name }}" class="field-item field-item-input" {% include "django/forms/widgets/attrs.html" %}>
    <el-input v-model="value" :type="type" :name="name" style="width: 400px;" :disabled="disabled"></el-input>
</div>
<script>
    var value = '{{ widget.value }}'
    var filed_value = ''
    if (value == '' || value == 'None') {
        filed_value = ''
    }else{
        filed_value = value
    }
    if ('{{ widget.el_disabled }}' == 'True') {
        disabled = true
    }else{
        disabled = false
    }
    new Vue({
        el: '#app_{{ widget.name }}',
        data: {
            type: '{{ widget.type }}',
            name: '{{ widget.name }}',
            value: filed_value,
            field_name: '{{ widget.field_name }}',
            disabled: disabled
        },
    })
</script>
<style>
    .field-item-input{
        height: 34px;
    }
</style>